Pflacs means faster load-cases and parameter studies.

Development of `pflacs` is currently in alpha phase. Python versions 3.6+ only are supported.

For details, see the [`pflacs` documentation](https://qwilka.github.io/pflacs/).
